@@ -140,8 +140,29 @@ import aws_cdk.aws_lambda_event_sources
 import aws_cdk.core
 
 
-class DynamoDBStreamToLambdaToElasticSearchAndKibana(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-solutions-constructs/aws-dynamodb-stream-lambda-elasticsearch-kibana.DynamoDBStreamToLambdaToElasticSearchAndKibana"):
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, deploy_lambda: bool, domain_name: str, dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps]=None, dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps]=None, es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps]=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table]=None, lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps]=None) -> None:
+class DynamoDBStreamToLambdaToElasticSearchAndKibana(
+    aws_cdk.core.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-solutions-constructs/aws-dynamodb-stream-lambda-elasticsearch-kibana.DynamoDBStreamToLambdaToElasticSearchAndKibana",
+):
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        deploy_lambda: bool,
+        domain_name: str,
+        dynamo_event_source_props: typing.Optional[
+            aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps
+        ] = None,
+        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
+        es_domain_props: typing.Optional[
+            aws_cdk.aws_elasticsearch.CfnDomainProps
+        ] = None,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+    ) -> None:
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
@@ -161,9 +182,20 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(aws_cdk.core.Construct, met
         summary:
         :summary:: Constructs a new instance of the LambdaToDynamoDB class.
         """
-        props = DynamoDBStreamToLambdaToElasticSearchAndKibanaProps(deploy_lambda=deploy_lambda, domain_name=domain_name, dynamo_event_source_props=dynamo_event_source_props, dynamo_table_props=dynamo_table_props, es_domain_props=es_domain_props, existing_lambda_obj=existing_lambda_obj, existing_table_obj=existing_table_obj, lambda_function_props=lambda_function_props)
+        props = DynamoDBStreamToLambdaToElasticSearchAndKibanaProps(
+            deploy_lambda=deploy_lambda,
+            domain_name=domain_name,
+            dynamo_event_source_props=dynamo_event_source_props,
+            dynamo_table_props=dynamo_table_props,
+            es_domain_props=es_domain_props,
+            existing_lambda_obj=existing_lambda_obj,
+            existing_table_obj=existing_table_obj,
+            lambda_function_props=lambda_function_props,
+        )
 
-        jsii.create(DynamoDBStreamToLambdaToElasticSearchAndKibana, self, [scope, id, props])
+        jsii.create(
+            DynamoDBStreamToLambdaToElasticSearchAndKibana, self, [scope, id, props]
+        )
 
     @builtins.property
     @jsii.member(jsii_name="cloudwatchAlarms")
@@ -201,9 +233,37 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(aws_cdk.core.Construct, met
         return jsii.get(self, "userPoolClient")
 
 
-@jsii.data_type(jsii_type="@aws-solutions-constructs/aws-dynamodb-stream-lambda-elasticsearch-kibana.DynamoDBStreamToLambdaToElasticSearchAndKibanaProps", jsii_struct_bases=[], name_mapping={'deploy_lambda': 'deployLambda', 'domain_name': 'domainName', 'dynamo_event_source_props': 'dynamoEventSourceProps', 'dynamo_table_props': 'dynamoTableProps', 'es_domain_props': 'esDomainProps', 'existing_lambda_obj': 'existingLambdaObj', 'existing_table_obj': 'existingTableObj', 'lambda_function_props': 'lambdaFunctionProps'})
-class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps():
-    def __init__(self, *, deploy_lambda: bool, domain_name: str, dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps]=None, dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps]=None, es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps]=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table]=None, lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/aws-dynamodb-stream-lambda-elasticsearch-kibana.DynamoDBStreamToLambdaToElasticSearchAndKibanaProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "deploy_lambda": "deployLambda",
+        "domain_name": "domainName",
+        "dynamo_event_source_props": "dynamoEventSourceProps",
+        "dynamo_table_props": "dynamoTableProps",
+        "es_domain_props": "esDomainProps",
+        "existing_lambda_obj": "existingLambdaObj",
+        "existing_table_obj": "existingTableObj",
+        "lambda_function_props": "lambdaFunctionProps",
+    },
+)
+class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
+    def __init__(
+        self,
+        *,
+        deploy_lambda: bool,
+        domain_name: str,
+        dynamo_event_source_props: typing.Optional[
+            aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps
+        ] = None,
+        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
+        es_domain_props: typing.Optional[
+            aws_cdk.aws_elasticsearch.CfnDomainProps
+        ] = None,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+    ) -> None:
         """
         :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
         :param domain_name: Cognito & ES Domain Name. Default: - None
@@ -217,20 +277,36 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps():
         summary:
         :summary:: The properties for the DynamoDBStreamToLambdaToElastciSearchAndKibana Construct
         """
-        if isinstance(dynamo_event_source_props, dict): dynamo_event_source_props = aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps(**dynamo_event_source_props)
-        if isinstance(dynamo_table_props, dict): dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
-        if isinstance(es_domain_props, dict): es_domain_props = aws_cdk.aws_elasticsearch.CfnDomainProps(**es_domain_props)
-        if isinstance(lambda_function_props, dict): lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+        if isinstance(dynamo_event_source_props, dict):
+            dynamo_event_source_props = aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps(
+                **dynamo_event_source_props
+            )
+        if isinstance(dynamo_table_props, dict):
+            dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
+        if isinstance(es_domain_props, dict):
+            es_domain_props = aws_cdk.aws_elasticsearch.CfnDomainProps(
+                **es_domain_props
+            )
+        if isinstance(lambda_function_props, dict):
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
+                **lambda_function_props
+            )
         self._values = {
-            'deploy_lambda': deploy_lambda,
-            'domain_name': domain_name,
+            "deploy_lambda": deploy_lambda,
+            "domain_name": domain_name,
         }
-        if dynamo_event_source_props is not None: self._values["dynamo_event_source_props"] = dynamo_event_source_props
-        if dynamo_table_props is not None: self._values["dynamo_table_props"] = dynamo_table_props
-        if es_domain_props is not None: self._values["es_domain_props"] = es_domain_props
-        if existing_lambda_obj is not None: self._values["existing_lambda_obj"] = existing_lambda_obj
-        if existing_table_obj is not None: self._values["existing_table_obj"] = existing_table_obj
-        if lambda_function_props is not None: self._values["lambda_function_props"] = lambda_function_props
+        if dynamo_event_source_props is not None:
+            self._values["dynamo_event_source_props"] = dynamo_event_source_props
+        if dynamo_table_props is not None:
+            self._values["dynamo_table_props"] = dynamo_table_props
+        if es_domain_props is not None:
+            self._values["es_domain_props"] = es_domain_props
+        if existing_lambda_obj is not None:
+            self._values["existing_lambda_obj"] = existing_lambda_obj
+        if existing_table_obj is not None:
+            self._values["existing_table_obj"] = existing_table_obj
+        if lambda_function_props is not None:
+            self._values["lambda_function_props"] = lambda_function_props
 
     @builtins.property
     def deploy_lambda(self) -> bool:
@@ -241,7 +317,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps():
         default
         :default: - true
         """
-        return self._values.get('deploy_lambda')
+        return self._values.get("deploy_lambda")
 
     @builtins.property
     def domain_name(self) -> str:
@@ -250,16 +326,18 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps():
         default
         :default: - None
         """
-        return self._values.get('domain_name')
+        return self._values.get("domain_name")
 
     @builtins.property
-    def dynamo_event_source_props(self) -> typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps]:
+    def dynamo_event_source_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps]:
         """Optional user provided props to override the default props.
 
         default
         :default: - Default props are used
         """
-        return self._values.get('dynamo_event_source_props')
+        return self._values.get("dynamo_event_source_props")
 
     @builtins.property
     def dynamo_table_props(self) -> typing.Optional[aws_cdk.aws_dynamodb.TableProps]:
@@ -268,16 +346,18 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps():
         default
         :default: - Default props are used
         """
-        return self._values.get('dynamo_table_props')
+        return self._values.get("dynamo_table_props")
 
     @builtins.property
-    def es_domain_props(self) -> typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps]:
+    def es_domain_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps]:
         """Optional user provided props to override the default props for the API Gateway.
 
         default
         :default: - Default props are used
         """
-        return self._values.get('es_domain_props')
+        return self._values.get("es_domain_props")
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -288,7 +368,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps():
         default
         :default: - None
         """
-        return self._values.get('existing_lambda_obj')
+        return self._values.get("existing_lambda_obj")
 
     @builtins.property
     def existing_table_obj(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
@@ -297,10 +377,12 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps():
         default
         :default: - None
         """
-        return self._values.get('existing_table_obj')
+        return self._values.get("existing_table_obj")
 
     @builtins.property
-    def lambda_function_props(self) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
+    def lambda_function_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
         """Optional user provided props to override the default props.
 
         If ``deploy`` is set to true only then this property is required
@@ -308,7 +390,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps():
         default
         :default: - Default props are used
         """
-        return self._values.get('lambda_function_props')
+        return self._values.get("lambda_function_props")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -317,7 +399,9 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'DynamoDBStreamToLambdaToElasticSearchAndKibanaProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "DynamoDBStreamToLambdaToElasticSearchAndKibanaProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
