@@ -20,7 +20,12 @@ import aws_solutions_constructs.aws_lambda_elasticsearch_kibana._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-solutions-constructs/aws-dynamodb-stream-lambda-elasticsearch-kibana", "1.47.0", __name__[0:-6], "aws-dynamodb-stream-lambda-elasticsearch-kibana@1.47.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-solutions-constructs/aws-dynamodb-stream-lambda-elasticsearch-kibana",
+    "1.48.0",
+    __name__[0:-6],
+    "aws-dynamodb-stream-lambda-elasticsearch-kibana@1.48.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
